#!/bin/bash
#SBATCH --job-name=vInt
#SBATCH --ntasks=1
#SBATCH --cpus-per-task=8        # Añadir para aprovechar paralelización interna
#SBATCH --output=logs/vert_int_%j.out
#SBATCH --error=logs/vert_int_%j.err
#SBATCH --time=5:00:00
#SBATCH --account=bsc32          # Añadir = después del parámetro
#SBATCH --qos=bsc_es             # Añadir = después del parámetro


# Configuración más robusta de variables
export EXPID="a936"
export START_DATE="2018-01-01"
export END_DATE="2018-04-30"
export OUTPUT_DIR="/esarchive/scratch/hnavarro/InterpolatedVertData"
export STATION_FILE="stations_2018_jordi.json"

# Crear directorio de logs si no existe
mkdir -p logs

# Cargar módulos (mejor con verificación)
if ! source load_modules.sh 2>> logs/modules_${SLURM_JOB_ID}.err; then
    echo "Error loading modules" >&2
    exit 1
fi

# Verificar existencia de archivos
if [[ ! -f "$STATION_FILE" ]]; then
    echo "Station file $STATION_FILE not found!" >&2
    exit 1
fi

# Ejecución con verificación de éxito
if srun --mpi=pmi2 --cpu-bind=cores --distribution=cyclic:cyclic \
    /apps/SINGULARITY/extras/nord3_singu_es python -u vertint_mainv03.py \
    --expid "$EXPID" \
    --start_date "$START_DATE" \
    --end_date "$END_DATE" \
    --output_dir "$OUTPUT_DIR" \
    --station_file "$STATION_FILE"; then
    echo "Job $SLURM_JOB_ID completed successfully at $(date)" >> logs/vert_int_${SLURM_JOB_ID}.status
    exit 0
else
    echo "Job $SLURM_JOB_ID FAILED at $(date)" >> logs/vert_int_${SLURM_JOB_ID}.status
    exit 1
fi